==> siag_3.1.22.orig.tar.gz: siag-3.1.22/xegon/app-defaults.h <==
"Egon.geometry:			600x400",
"Egon*combo_viewport.allowHoriz:	False",
"Egon*submenu.translations:      #override                       \\n\
        :<EnterWindow>:         highlight()                     \\n\
        :<LeaveWindow>:         MenuPopdown() unhighlight()     \\n\
        :<BtnMotion>:           highlight()                     \\n\
        :<BtnUp>:               popdown-submenu() notify() unhighlight()",
"Egon*edit_shell.geometry:	600x300",
"Egon*textframe.topShadowContrast:	-40",
"Egon*textframe.bottomShadowContrast:	-20",
"Egon*topbox.xLayout:		100%",
"Egon*topbox.yLayout:		30 30 30 30 100% 30",
"Egon*topbox*List*background:	white",
"Egon*topbox.MenuButton.shadowWidth:	0",
"Egon*topbox.Toggle.shadowWidth:		0",
"Egon*topbox.Command.shadowWidth:	0",
"Egon*menubar.gridy:			0",
"Egon*menubar.shadowWidth:		1",
"Egon*menubox.MenuButton.shadowWidth:	0",
"Egon*menubox.MenuButton.internalHeight:	6",
"Egon*menubox.SiagMenuButton.shadowWidth:	0",
"Egon*menubox.SiagMenuButton.internalHeight:	6",
"Egon*menubox.orientation:		horizontal",
"Egon*menubox.borderWidth:		0",
"Egon*menubox.vSpace:			0",
"Egon*menubox.hSpace:			0",
"Egon*toolbar.gridy:			1",
"Egon*toolbar.shadowWidth:		1",
"Egon*toolbox.Toggle.shadowWidth:		0",
"Egon*toolbox.Command.shadowWidth:	0",
"Egon*toolbox.orientation:		horizontal",
"Egon*toolbox.borderWidth:		0",
"Egon*toolbox.vSpace:			0",
"Egon*toolbox.hSpace:			0",
"Egon*formatbar.gridy:			2",
"Egon*formatbar.shadowWidth:		1",
"Egon*formatbox.vSpace:			0",
"Egon*formatbox.hSpace:			0",
"Egon*formatbox.Toggle.shadowWidth:	0",
"Egon*formatbox.Command.shadowWidth:	0",
"Egon*formatbox.orientation:		horizontal",
"Egon*formatbox.borderWidth:		0",
"Egon*formatframe.topShadowContrast:	-40",
"Egon*formatframe.bottomShadowContrast:	-20",
"Egon*formatframe.shadowWidth:		1",
"Egon*formatframe.height:		20",
"Egon*formatframe.borderWidth:		4",
"Egon*formatframe.borderColor:		grey",
"Egon*formatframe.allowResize:		False",
"Egon*Box.handle.width:			9",
"Egon*Box.handle.height:			28",
"Egon*Box.handle.label:",
"Egon*textbox.gridy:			3",
"Egon*textbox.borderWidth:		0",
"Egon*textbox.xLayout:			4 100% 4",
"Egon*textbox.yLayout:			4 100% 4",
"Egon*label1.font:			-*-helvetica-medium-r-*-12-*",
"Egon*label1.gridx:			1",
"Egon*label1.gridy:			1",
"Egon*gridpane.gridy:			4",
"Egon*gridpane.borderWidth:		0",
"Egon*statusbox.gridy:			5",
"Egon*statusbox.borderWidth:		0",
"Egon*statusbox.xLayout:			4 100% 4 100 4",
"Egon*statusbox.yLayout:			4 100% 4",
"Egon*label2.font:			-*-helvetica-medium-r-*-12-*",
"Egon*label2.shadowWidth:		1",
"Egon*label2.gridx:			1",
"Egon*label2.gridy:			1",
"Egon*label3.font:			-*-helvetica-medium-r-*-12-*",
"Egon*label3.shadowWidth:		1",
"Egon*label3.gridx:			3",
"Egon*label3.gridy:			1",
"Egon*viewport.xLayout:			2 50% 2 100 2 50% 2",
"Egon*viewport.yLayout:			2 100% 2",
"Egon*objf.gridx:			1",
"Egon*objf.gridy:			1",
"Egon*objf.shadowType:			Groove",
"Egon*objf.allowResize:			False",
"Egon*objf.marginWidth:			2",
"Egon*objf.marginHeight:			2",
"Egon*objv.borderWidth:			0",
"Egon*tickf.gridx:			3",
"Egon*tickf.gridy:			1",
"Egon*tickf.shadowType:			Groove",
"Egon*tickf.allowResize:			False",
"Egon*tickf.marginWidth:			2",
"Egon*tickf.marginHeight:		2",
"Egon*tickv.borderWidth:			0",
"Egon*propf.gridx:			5",
"Egon*propf.gridy:			1",
"Egon*propf.shadowType:			Groove",
"Egon*propf.allowResize:			False",
"Egon*propf.marginWidth:			2",
"Egon*propf.marginHeight:		2",
"Egon*propv.borderWidth:			0",
"Egon*frame.shadowWidth:			1",
"Egon*vsep.width:			2",
"Egon*vsep.height:			24",
"Egon*vsep.borderWidth:			2",
"Egon*vsep.borderColor:			grey",
"Egon*vsep.shadowWidth:			1",
"Egon*vsep.topShadowContrast:		-40",
"Egon*vsep.bottomShadowContrast:		-20",
"Egon*topbox.translations:	#override			\\n\
	<Key>F1:		siaghelp(egon.html)",
"Egon*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Egon*tbOpen.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()	\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbSave.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbView.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbPrint.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbQuit.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip(Pop down animation)\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbStop.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbPrev.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbPlay.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbNext.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbHelp.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*tbCopy.translations:	#override				\\n\
	<Enter>:	siag-highlight(1)\
			tooltip()\\n\
	<Leave>:	siag-unhighlight(0)\
			draw-input()",
"Egon*toolbar_toggle.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\\n\
	<Leave>:	siag-unhighlight(0 1)",
"Egon*cmdItalic.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\
			tooltip()	\\n\
	<Leave>:	siag-unhighlight(0 1)\
			draw-input()",
"Egon*cmdHLeft.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\
			tooltip(Left adjusted text)	\\n\
	<Leave>:	siag-unhighlight(0 1)\
			draw-input()",
"Egon*cmdHCenter.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\
			tooltip(Centered text)	\\n\
	<Leave>:	siag-unhighlight(0 1)\
			draw-input()",
"Egon*cmdHRight.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\
			tooltip(Right adjusted text)	\\n\
	<Leave>:	siag-unhighlight(0 1)\
			draw-input()",
"Egon*viewport.left:	ChainLeft",
"Egon*viewport.right:	ChainRight",
"Egon*viewport.top:	ChainTop",
"Egon*viewport.bottom:	ChainBottom",
"Egon*viewport.height:	200",
"Egon*viewport.width:	600",
"Egon*grid.background:		white",
"Egon*grid.left:			ChainLeft",
"Egon*grid.right:			ChainRight",
"Egon*grid.top:			ChainTop",
"Egon*grid.bottom:			ChainBottom",
"Egon*stage.translations:\
	:<Btn3Down>:		place-shortcuts() XtMenuPopup(shortcuts)",
"Egon*viewport.translations:\
	:<Key>Home:		execute(beginning-of-line)		\\n\
	Ctrl<Key>a:		execute(beginning-of-line)		\\n\
	:<Key>End:		execute(end-of-line)			\\n\
	Ctrl<Key>e:		execute(end-of-line)			\\n\
	Ctrl<Key>space:		execute(set-mark-command)		\\n\
	:<Key>Left:		execute(backward-char)			\\n\
	Ctrl<Key>b:		execute(backward-char)			\\n\
	:<Key>Delete:		execute(delete-char)			\\n\
	Ctrl<Key>d:		execute(delete-char)			\\n\
	:<Key>BackSpace:	execute(delete-char-backward)		\\n\
	:<Key>Right:		execute(forward-char)			\\n\
	Ctrl<Key>f:		execute(forward-char)			\\n\
	:<Key>Down:		execute(next-line)			\\n\
	Ctrl<Key>n:		execute(next-line)			\\n\
	Ctrl<Key>o:		execute(split-line)			\\n\
	:<Key>Return:		execute(newline)			\\n\
	Ctrl<Key>k:		execute(kill-line)			\\n\
	Ctrl<Key>l:		execute(recenter)			\\n\
	Ctrl<Key>x,Ctrl<Key>f:	execute(load-buffer)			\\n\
	:<Key>Up:		execute(previous-line)			\\n\
	Ctrl<Key>p:		execute(previous-line)			\\n\
	Ctrl<Key>x,Ctrl<Key>c:	execute(quit-egon)			\\n\
	Ctrl<Key>x,Ctrl<Key>s:	execute(save-buffer)			\\n\
	Ctrl<Key>x,Ctrl<Key>w:	execute(save-buffer-as)			\\n\
	Ctrl<Key>x,Ctrl<Key>x:	execute(exchange-point-and-mark)	\\n\
	Ctrl<Key>x,Ctrl<Key>space: execute(set-block)			\\n\
	Meta<Key>x:		execute(execute-extended-command)	\\n\
	:Meta<Key>less:		execute(beginning-of-buffer)		\\n\
	:Meta<Key>greater:	execute(end-of-buffer)			\\n\
	:<Key>Page_Up:		execute(scroll-up)			\\n\
	Meta<Key>v:		execute(scroll-up)			\\n\
	:<Key>Page_Down:	execute(scroll-down)			\\n\
	Ctrl<Key>v:		execute(scroll-down)			\\n\
	Ctrl<Key>w:		execute(delete-block)			\\n\
	Ctrl<Key>x,<Key>question: execute(what-cursor-position)		\\n\
	Ctrl<Key>x,<Key>k:	execute(kill-buffer)			\\n\
	Ctrl<Key>x,<Key>b:	execute(switch-to-buffer)		\\n\
	Ctrl<Key>x,<Key>2:	execute(split-window-vertically)	\\n\
	Ctrl<Key>x,<Key>1:	execute(delete-other-windows)		\\n\
	Ctrl<Key>x,<Key>0:	execute(delete-window)			\\n\
	Ctrl<Key>x,<Key>o:	execute(other-window)			\\n\
	:<Key>F1:		execute(help-contents)			\\n\
	Ctrl<Key>h,<Key>c:	execute(help-contents)			\\n\
	:<Key>F4:		execute(more complicated test)",
"Egon*hscroll.left:			ChainLeft",
"Egon*hscroll.right:		ChainRight",
"Egon*hscroll.top:			ChainBottom",
"Egon*hscroll.bottom:		ChainBottom",
"Egon*hscroll.orientation:		Horizontal",
"Egon*vscroll.left:			ChainRight",
"Egon*vscroll.right:		ChainRight",
"Egon*vscroll.top:			ChainTop",
"Egon*vscroll.bottom:		ChainBottom",
"Egon*vscroll.orientation:		Vertical",
"Egon*font_pshell.x:		80",
"Egon*font_pshell.y:		80",
"Egon*font_okbutton.width:		80",
"Egon*font_cancelbutton.width:	80",
"Egon*alert*borderWidth:		0",
"Egon*alert*topbox.orientation:	vertical",
"Egon*alert*buttonbox.orientation:	horizontal",
"Egon*listshell*borderWidth:	0",
"Egon*listshell*topbox.orientation:	horizontal",
"Egon*listshell*listbox.orientation:	vertical",
"Egon*listshell*viewport.borderWidth:	1",
"Egon*listshell*buttonbox.orientation:	vertical",
"Egon*form_shell*MenuButton.shadowWidth:	1",

==> siag-3.6.0.tar.gz: siag-3.6.0/xegon/app-defaults.h <==
"Egon.geometry:			600x400",
"Egon*combo_viewport.allowHoriz:	False",
"Egon*edit_shell.geometry:	600x300",
"Egon*ani_shell.geometry:	600x400",
"Egon*textframe.topShadowContrast:	-40",
"Egon*textframe.bottomShadowContrast:	-20",
"Egon*topbox.xLayout:		100%",
"Egon*topbox.yLayout:		30 30 30 30 100% 30",
"Egon*topbox*List*background:	white",
"Egon*topbox.NwsMenuButton.shadowWidth:	0",
"Egon*topbox.Toggle.shadowWidth:		0",
"Egon*topbox.Command.shadowWidth:	0",
"Egon*menubar.gridy:			0",
"Egon*menubar.shadowWidth:		1",
"Egon*menubox.NwsMenuButton.shadowWidth:	0",
"Egon*menubox.NwsMenuButton.internalHeight:	6",
"Egon*menubox.orientation:		horizontal",
"Egon*menubox.borderWidth:		0",
"Egon*menubox.vSpace:			0",
"Egon*menubox.hSpace:			0",
"Egon*toolbar.gridy:			1",
"Egon*toolbar.shadowWidth:		1",
"Egon*toolbox.Toggle.shadowWidth:		0",
"Egon*toolbox.Command.shadowWidth:	0",
"Egon*toolbox.orientation:		horizontal",
"Egon*toolbox.borderWidth:		0",
"Egon*toolbox.vSpace:			0",
"Egon*toolbox.hSpace:			0",
"Egon*formatbar.gridy:			2",
"Egon*formatbar.shadowWidth:		1",
"Egon*formatbox.vSpace:			0",
"Egon*formatbox.hSpace:			0",
"Egon*formatbox.Toggle.shadowWidth:	0",
"Egon*formatbox.Command.shadowWidth:	0",
"Egon*formatbox.orientation:		horizontal",
"Egon*formatbox.borderWidth:		0",
"Egon*format_command.shadowWidth:		1",
"Egon*format_command.allowResize:		False",
"Egon*Box.handle.width:			9",
"Egon*Box.handle.height:			28",
"Egon*Box.handle.label:",
"Egon*textbox.gridy:			3",
"Egon*textbox.borderWidth:		0",
"Egon*textbox.xLayout:			4 100% 4",
"Egon*textbox.yLayout:			4 100% 4",
"Egon*label1.gridx:			1",
"Egon*label1.gridy:			1",
"Egon*gridpane.gridy:			4",
"Egon*gridpane.borderWidth:		0",
"Egon*statusbox.gridy:			5",
"Egon*statusbox.borderWidth:		0",
"Egon*statusbox.xLayout:			4 100% 4 100 4",
"Egon*statusbox.yLayout:			4 100% 4",
"Egon*label2.shadowWidth:		1",
"Egon*label2.gridx:			1",
"Egon*label2.gridy:			1",
"Egon*label3.shadowWidth:		1",
"Egon*label3.gridx:			3",
"Egon*label3.gridy:			1",
"Egon*viewport.xLayout:			2 50% 2 100 2 50% 2",
"Egon*viewport.yLayout:			2 100% 17 2",
"Egon*tabbox.gridx:			1",
"Egon*tabbox.gridy:			2",
"Egon*tabbox.gridWidth:			5",
"Egon*tabbox.xLayout:			25 25 100%",
"Egon*tabl.label:			<<",
"Egon*tabr.gridx:			1",
"Egon*tabr.label:			>>",
"Egon*tab.gridx:				2",
"Egon*objf.gridx:			1",
"Egon*objf.gridy:			1",
"Egon*objf.shadowType:			Groove",
"Egon*objf.allowResize:			False",
"Egon*objf.marginWidth:			2",
"Egon*objf.marginHeight:			2",
"Egon*objv.borderWidth:			0",
"Egon*tickf.gridx:			3",
"Egon*tickf.gridy:			1",
"Egon*tickf.shadowType:			Groove",
"Egon*tickf.allowResize:			False",
"Egon*tickf.marginWidth:			2",
"Egon*tickf.marginHeight:		2",
"Egon*tickv.borderWidth:			0",
"Egon*propf.gridx:			5",
"Egon*propf.gridy:			1",
"Egon*propf.shadowType:			Groove",
"Egon*propf.allowResize:			False",
"Egon*propf.marginWidth:			2",
"Egon*propf.marginHeight:		2",
"Egon*propv.borderWidth:			0",
"Egon*frame.shadowWidth:			1",
"Egon*vsep.width:			2",
"Egon*vsep.height:			24",
"Egon*vsep.borderWidth:			2",
"Egon*vsep.shadowWidth:			1",
"Egon*vsep.topShadowContrast:		-40",
"Egon*vsep.bottomShadowContrast:		-20",
"Egon*topbox.translations:	#override			\\n\
	<Key>F1:		siaghelp(egon.html)",
"Egon*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Egon*toolbar_toggle.translations:		#override	\\n\
	<Enter>:	siag-highlight(1 1)\\n\
	<Leave>:	siag-unhighlight(0 1)",
"Egon*viewport.height:	200",
"Egon*viewport.width:	600",
"Egon*grid.background:		white",
"Egon*stage.gradient:		100 100 128 0 1 black blue",
"Egon*stage.translations:\
	:<Btn1Down>:		execute(next-page)		\\n\
	:<Btn3Down>:		place-shortcuts() XtMenuPopup(shortcuts) \\n\
	<Key>h:			execute(popdown-stage)		\\n\
	<Key>o:			execute(popdown-stage) execute(load-buffer) \\n\
	<Key>q:			execute(quit-program)		\\n\
	<Key>s:			execute(ani-ctl ANI_STOP 0)	\\n\
	<Key>p:			execute(ani-ctl ANI_PREVIOUS 0)	\\n\
	<Key>n:			execute(ani-ctl ANI_NEXT 0)	\\n\
	<Key>c:			execute(ani-ctl ANI_CONTINUE 0)	\\n\
	<Key>space:		execute(next-page)		\\n\
	<Key>BackSpace:		execute(previous-page)",
"Egon*hscroll.orientation:		Horizontal",
"Egon*vscroll.orientation:		Vertical",
"Egon*font_pshell.x:		80",
"Egon*font_pshell.y:		80",
"Egon*font_okbutton.width:		80",
"Egon*font_cancelbutton.width:	80",
"Egon*alert*borderWidth:		0",
"Egon*alert*topbox.orientation:	vertical",
"Egon*alert*buttonbox.orientation:	horizontal",
"Egon*listshell*borderWidth:	0",
"Egon*listshell*topbox.orientation:	horizontal",
"Egon*listshell*listbox.orientation:	vertical",
"Egon*listshell*viewport.borderWidth:	1",
"Egon*listshell*buttonbox.orientation:	vertical",
"Egon*form_shell*NwsMenuButton.shadowWidth:	1",
